@@ -3,7 +3,7 @@ package Acme::CPANAuthors::Japanese;
 use strict;
 use warnings;
 
-our $VERSION = '0.140828';
+our $VERSION = '0.150912';
 
 use Acme::CPANAuthors::Register (
     ABUI      => 'DAISUKE ABUI',
@@ -18,6 +18,7 @@ use Acme::CPANAuthors::Register (
     AHIGUTI   => 'Akira Higuchi',
     AHIROSE   => 'Akira HIROSE',
     AINAME    => 'Satoshi Namai',
+    AJIYOSHI  => 'yoichi ajiyoshi',
     AKIHIRO   => 'Kodai Takahashi',
     AKIHITO   => 'Akihito Takeda',
     AKIRA     => 'Akira Hangai',
@@ -29,14 +30,17 @@ use Acme::CPANAuthors::Register (
     AMIMOTO   => 'Aki Mimoto',
     ANAZAWA   => 'Ryo Anazawa',
     ANNELI    => 'Yuki Izumi',
+    ANZUSAN   => 'masashi nakajima',
     AONEKO    => 'Atsushi Watanabe',
     AQL       => 'Tetsuya Toyoda',
     ARGRATH   => 'SHIRAKATA Kentaro',
     ARISAWA   => 'Kosuke Arisawa',
+    ARUHI     => 'Ryota Miki',
     ARUTEIDO  => 'satoshi ishikawa',
     ASAKURA   => 'ASAKURA Takuji',
     ASARIH    => 'Hiro Asari',
     ASKADNA   => 'Shinichiro Aska',
+    ASTJ      => 'Asato Wakisaka',
     AYANOKOUZ => 'AYANOKOUZI, Ryuunosuke',
     BANB      => 'ITO Nobuaki',
     BASHI     => 'Toshimasa Ishibashi',
@@ -46,7 +50,9 @@ use Acme::CPANAuthors::Register (
     BOKUTIN   => 'Tomohiro Hosaka',
     BONAR     => 'Nakano Kyohei',
     BOXPHERE  => 'Satoshi Ohkubo',
+    BWKIGPY   => 'Yoshifumi KODAMA',
     CASEY     => 'Keisuke Nagashima',
+    CATATSUY  => 'KANEKO Tatsuya',
     CHIBA     => 'Masahiro Chiba',
     CLAIRVY   => 'NAGAYA Shinichiro',
     CLCL      => 'OONO Yoshitaka',
@@ -74,6 +80,7 @@ use Acme::CPANAuthors::Register (
     FUKATA    => 'Tatsuya Fukata',
     FUKUDA    => 'Keisuke Fukuda',
     FUKUMURA  => 'Akinori Fukumura',
+    FUMIAKIY  => 'Fumiaki Yoshimatsu',
     FUTAYA    => 'Satoshi Futaya',
     GAOU      => 'Kazuharu Arakawa',
     GENKIST   => 'Genki Sato',
@@ -92,6 +99,7 @@ use Acme::CPANAuthors::Register (
     HATAK     => 'Hisashi HATAKEYAMA',
     HATENA    => 'Hatena',
     HATTORI   => 'Fumiaki Hattori',
+    HATZ      => 'TSUGIHITO SHIBAHATA',
     HAYAJO    => 'Hayato Imai',
     HAYASHI   => 'Hiroo HAYASHI',
     HDAICHI   => 'daichi hiroki',
@@ -128,10 +136,12 @@ use Acme::CPANAuthors::Register (
     HOKKE     => 'Yoichi Hirota',
     HOLLY     => 'Akira Horimoto',
     HORIUCHI  => 'Yasuhiro Horiuchi',
+    HORIYUKI  => 'Yukio HORI',
     HOTO      => 'Yuki Ishikawa',
     HOTSU     => 'Hiroaki Otsu',
     HRK       => 'Haruka Kataoka',
     HRYK      => 'Hiroyuki Nakamura',
+    HTK       => 'Hideaki Takahashi',
     HWAT      => 'WATANABE Hiroaki',
     ICHI      => 'Takuya Ichikawa',
     ICHIGOTAK => 'ichigotake',
@@ -157,8 +167,10 @@ use Acme::CPANAuthors::Register (
     JUDIOO    => 'Udo Oji',
     JUNICHIRO => 'Junichiro Tobe',
     JUNNAMA   => 'Junnama Noda',
+    KAKUDRUMS => 'Yoichi Watanabe',
     KAMIPO    => 'Ryuta Kamizono',
     KAMO      => 'Yoshikazu Kamoshida',
+    KAORUO    => 'Kaoru Oshita',
     KARUPA    => 'Kenta Sato',
     KASHIWABA => 'Nobuyuki Kashiwabara',
     KAWABATA  => 'KAWABATA Kazumichi',
@@ -175,6 +187,7 @@ use Acme::CPANAuthors::Register (
     KENSHIN   => 'Kenshin YAMADA',
     KENTARO   => 'Kentaro Kuribayashi',
     KEYAMB    => 'YASUTAKE Kiyoshi',
+    KFLY      => 'Kenta Kobayashi',
     KIMATA    => 'Tetsuya KIMATA',
     KIMOTO    => 'Yuki Kimoto',
     KIMURA    => 'Takeshi Kimura',
@@ -199,6 +212,7 @@ use Acme::CPANAuthors::Register (
     KOMORIYA  => 'Kazunari Komoriya',
     KONDO     => 'Yoshiyuki KONDO',
     KOPUG     => 'Masahiro Funakoshi',
+    KOSEI     => 'Kosei Moriyama',
     KOSHITA   => 'Kaoru Oshita',
     KOYACHI   => 'Tsutomu Koyachi',
     KPEE      => 'Kiyoaki KATAKURA',
@@ -210,6 +224,7 @@ use Acme::CPANAuthors::Register (
     KUBOTA    => 'Tomohiro KUBOTA',
     KUMA      => 'KUMAGAI Kentaro',
     KUMAKATSU => 'katsuki ookuma',
+    KUNIWAK   => 'Yuki Kokubun',
     KUNIYOSHI => 'Kuniyoshi Kouji',
     KURAMAKO  => 'makoto',
     KURIHARA  => 'Yoshiki KURIHARA',
@@ -252,11 +267,15 @@ use Acme::CPANAuthors::Register (
     MASAO     => 'Masao Kitamura',
     MASAP     => 'Masahiro Funakoshi',
     MASARTZ   => 'Masaru Hoshino',
+    MASASHI   => 'masashi ogawa',
+    MASASUZU  => 'SUZUKI Masashi',
     MASH      => 'Masakazu Ohtsuka',
+    MASIUCHI  => 'Masahiro Iuchi',
     MASUTARO  => 'Kotaro MASUDA',
     MATSUMOTO => 'syushi matsumoto',
     MATTN     => 'Yasuhiro Matsumoto',
     MERU      => 'meru_akimbo',
+    MIHYAERU  => 'Atsushi Takano',
     MIKAGE    => 'SANO Taku',
     MIKI      => 'Takeshi Miki',
     MIKIHOSHI => 'KAN Fushihara',
@@ -268,12 +287,14 @@ use Acme::CPANAuthors::Register (
     MIYAMUKO  => 'MIYAMUKO Katsuyuki',
     MIYAZAKI  => 'Ittetsu Miyazaki',
     MIZZY     => 'Gosuke Miyashita',
+    MNACAMURA => 'Mitsuhiro Nakamura',
     MONMON    => 'Nobuo Kumagai',
     MORIYA    => 'Moriya Masaki',
     MOSA      => 'Yusuke Enomoto',
     MOTEMEN   => 'motemen',
     MOZNION   => 'Taiki Kawakami',
     MRMT      => 'Jun Morimoto',
+    MSASASAKI => 'Masafumi Sasaki',
     MSHIGE    => 'shigeharu matsumoto',
     MUGENKEN  => 'Mugen Kenichi',
     MUGIFLY   => 'Masanori Ohgita',
@@ -290,6 +311,7 @@ use Acme::CPANAuthors::Register (
     NAKAYAMA  => 'Yasuhiro Nakayama',
     NANTO     => 'nanto_vi (TOYAMA Nao)',
     NANZOU    => 'Takaaki Mizuno',
+    NAOHIRO   => 'Naoya Hirota',
     NAOKIURAI => 'Naoki URAI',
     NAOY      => 'Naoyuki Ito',
     NAOYA     => 'Naoya Ito',
@@ -323,6 +345,7 @@ use Acme::CPANAuthors::Register (
     OINUME    => 'Kazuhiro Oinuma',
     OISHI     => 'Eisuke Oishi',
     OKAMUUU   => 'Masao Okamura',
+    OKAZUDM   => 'Kazuma Okada',
     OKLAHOMER => 'Go Hagiwara',
     ONISHI    => 'Yasuhiro Onishi',
     OPPARA    => 'oppara',
@@ -338,9 +361,11 @@ use Acme::CPANAuthors::Register (
     PIA       => 'Michiya Honda',
     PIROLIX   => 'Hiroyuki UENISHI',
     POCKET    => 'Masato Sogame',
+    POKUTUNA  => 'POKUDA Tunahiko',
     POPPEN    => 'Shinsuke Matsui',
     PUNYTAN   => 'punipuni',
     QAZXSWEDC => 'hiroshi morimoto',
+    QBTCFAHX  => 'Naoki SUDA',
     QUEEN     => 'Yasuhiro Miyazaki',
     RIMFS     => 'Yuichiro Tanaka',
     RINSATO   => 'takashi sato',
@@ -352,11 +377,13 @@ use Acme::CPANAuthors::Register (
     RYMIZUKI  => 'ryo iinuma',
     RYO       => 'Ryo Utsunomiya',
     RYOCHIN   => 'Okamoto RYO',
+    RYOPEKO   => 'Ryoichi SEKIGUCHI',
     SADAHIRO  => 'SADAHIRO Tomoyuki',
     SASAKURE  => 'Kei Shimada (sasakure_kei)',
     SASAO     => 'SASAO Takahiro',
     SASATA    => 'Tatsuya "sasata299" Sasaki',
     SASAZUKA  => 'Seiji Sasazuka',
+    SATETSU   => 'shotaro akiyama',
     SATOH     => 'cho45 (SATOH, Hiroh)',
     SATOSIN   => 'Shinichiro Sato',
     SATZZ     => 'Akihiko SATODA',
@@ -377,13 +404,16 @@ use Acme::CPANAuthors::Register (
     SHIKONO   => 'Shinji KONO',
     SHIMAZU   => 'Yuki SHIMAZU',
     SHIMI     => 'Kazuhito Shimizu',
+    SHINCHIT  => 'Takahiro Shinchi',
     SHINGT    => 'Shinichi Goto',
     SHINPEI   => 'HAYASHI, Shinpei',
     SHIRAIWA  => 'Kazuma Shiraiwa',
     SHMORIMO  => 'Shigeki Morimoto',
     SHOGO     => 'Shogo Ichinose',
     SHOHEIK   => 'Shohei Kameda',
+    SHOJIKAI  => 'Shoji Kai',
     SHOT      => 'Shota Takayama',
+    SIXEIGHT  => 'Tomohiro Nishimura',
     SKAJI     => 'Shoichi Kaji',
     SKJM      => 'Shin Kojima',
     SKONNO    => 'Satoshi Konno',
@@ -391,12 +421,15 @@ use Acme::CPANAuthors::Register (
     SKYFIVE   => 'Takeshi Ohishi',
     SNGJOKEN  => 'Shingo Kikugawa',
     SNUMANO   => 'Shugo Numano',
+    SOENO     => 'Kazumichi Soeno',
     SOH       => 'Soh Kitahara',
     SOHASHI   => 'Sean Ohashi',
+    SOJIRO    => 'Taishi Hiraga',
     SONGMU    => 'Masayuki Matsuki',
     SOTSA     => 'Shinichiro Sato',
     SPRINGMT  => 'Makoto Haruyama',
     SSEI      => 'Shinichiro Sei',
+    SSHIN     => 'Shintaro Seki',
     STAKASHIO => 'Shin Takashio',
     SUENAGA   => 'Hiroki Suenaga',
     SUGA      => 'suga masashi',
@@ -420,6 +453,7 @@ use Acme::CPANAuthors::Register (
     TAKASH    => 'shuhei takahashi',
     TAKASHI   => 'Takashi Saeki',
     TAKAYUKI  => 'Takayuki Ikeda',
+    TAKEBAYAS => 'Shun Takebayashi',
     TAKEFUMI  => 'KIMURA, takefumi',
     TAKEO     => 'Takeo Suzuki',
     TAKERU    => 'Takeru INOUE',
@@ -444,6 +478,7 @@ use Acme::CPANAuthors::Register (
     TATENO    => 'Yuichi Tateno',
     TATSUYAGI => 'Tatsuya Yagi',
     TAWAN     => 'Taro Funaki',
+    TEBORA    => 'Issei Horie',
     THORIKAWA => 'Takahiro Horikawa',
     TISHIDUKA => 'Takeshi ISHIDUKA',
     TKURITA   => 'Tetsuro KURITA',
@@ -458,6 +493,7 @@ use Acme::CPANAuthors::Register (
     TOHAE     => 'tohae wakizaka',
     TOKUBASS  => 'Kouji Tominaga',
     TOKUHIROM => 'MATSUNO Tokuhiro',
+    TOMBO     => 'Tomoaki Otsuka',
     TOMITA    => 'Naoki Tomita',
     TOMYHERO  => 'Tomohiro Teranishi',
     TONODERA  => 'Takahiro Onodera',
@@ -488,6 +524,7 @@ use Acme::CPANAuthors::Register (
     USUALOMA  => 'Taku Amano',
     UTAANI    => 'Takeshi Ueno',
     VPAM      => 'singo suda',
+    WADACHI   => 'Satoshi Wada',
     WAKAPON   => 'ASANO Kazunari',
     WATA      => 'Kouji Watanabe',
     WATANABE  => 'WATANABE Hirofumi',
@@ -503,6 +540,7 @@ use Acme::CPANAuthors::Register (
     YANBE     => 'Yusuke Yanbe',
     YANMAR    => 'Yamamoto Keiichiro',
     YANOTHER  => 'Daisuke (yet another) Maki',
+    YANUTETSU => 'satoshi yanuma',
     YAPPO     => 'Kazuhiro Osawa',
     YASU      => 'Yasushi Saito',
     YASUHIRO  => 'Yasuhiro Onishi',
@@ -510,7 +548,9 @@ use Acme::CPANAuthors::Register (
     YAYOHEI   => 'Yohei Yamamoto',
     YIBE      => 'Yuki Ibe',
     YISHINO   => 'Yukio Ishino',
+    YOHEIMUTA => 'Yohei Yoshimuta',
     YOKKUNS   => 'Yohei Sato',
+    YONJOUHAN => 'Tetsuya Yamamoto',
     YOSHIAKI  => 'Yoshiaki Shiokawa',
     YOSHIDA   => 'Hironori Yoshida',
     YOSHIMI   => 'Keiji Yoshimi',
@@ -536,6 +576,7 @@ use Acme::CPANAuthors::Register (
     YUTACHI   => 'Yutaka Kuno',
     YUUKI     => 'Yuuki Tsubouchi',
     YUYAW     => 'Yuya Watanabe',
+    YUZO      => 'Yuzo Iwasaki',
     YWATASE   => 'Yusuke Watase',
     ZENTOOO   => 'Naosuke Yokoe',
     ZIGOROU   => 'Toru Yamaguchi',
